.. Copyright NTESS. See COPYRIGHT file for details.

   SPDX-License-Identifier: MIT

.. _presentation-use-cases:

Use Cases and demonstrations
============================

Development environments
------------------------

- Using canary to test locally on a developer's laptop or desktop.

HPC workflows
-------------

- Efficiently managing large test suites on an HPC system.
- Example: Integration with an HPC scheduler for a real-world application.

Toolchain integration
---------------------

- Demonstrating a workflow with CMake, CDash, and GitLab
- Show how canary automates and accelerates CI/CD pipelines.
